pub(crate) fn new_group_send_first_message(context: &Context) -> String
Stock string: Others will only see this group after you sent a first message..
Others will only see this group after you sent a first message.